﻿using GrapeCity.Documents.Drawing;
using GrapeCity.Documents.Imaging;
using GrapeCity.Documents.Text;
using System;
using System.Collections.Generic;
using System.Drawing;
using System.IO;
using System.Text;

namespace ProductCatalogDemo
{
    class Catalog
    {
        public void GenerateCatalog()
        {
            using (var bmp = new GcBitmap(420, 400, true))
            using (var g = bmp.CreateGraphics(Color.White))
            {
                using (var img = Image.FromFile(@"Images\eCommerceProduct.png"))                
                {
                    //Draw the product image on target bitmap
                    g.DrawImage(img, new RectangleF(2, 10, 400, 400), null, ImageAlign.ScaleImage);
                }

                //Render the discount tag
                var semiTransparentColor = Color.FromArgb(100, Color.Red);                
                var path = CreatePath(new RectangleF(200, 15, 210, 210), g);
                g.FillPath(path, semiTransparentColor);
                g.DrawPath(path, semiTransparentColor);

                //Add text to the dicount tag
                // TextFormat class is used throughout all GcImaging text rendering to specify
                // font and other character formatting:
                var tf = new TextFormat()
                {
                    Font = Font.FromFile(@"Fonts\times.ttf"),
                    FontSize = 36
                };
                g.DrawString(
                    "50% OFF",
                    tf,
                    new RectangleF(260, 80, 100, 100), // the layout rectangle                    
                    TextAlignment.Center,   // Center text align
                    ParagraphAlignment.Center, // Center para align
                    true); // word wrap
                bmp.SaveAsJpeg("discounticon.jpg");
            }
        }

        //Define and return the graphic path for creating discount tag
        public IPath CreatePath(RectangleF rc, GcGraphics g)
        {
            var c = new PointF(310, 123);
            float r1 = 100f;
            float r2 = 65f;
            var degreesToRadians = Math.PI / 180;

            var path = g.CreatePath();
            path.BeginFigure(new PointF(c.X + r1, c.Y));
            for (int i = 0; i < 15; i++)
            {
                var angle = (24 * i + 12) * degreesToRadians;
                path.AddLine(new PointF((float)(r2 * Math.Cos(angle)) + c.X, (float)(r2 * Math.Sin(angle)) + c.Y));
                angle = (24 * i + 24) * degreesToRadians;
                path.AddLine(new PointF((float)(r1 * Math.Cos(angle)) + c.X, (float)(r1 * Math.Sin(angle)) + c.Y));
            }
            path.EndFigure(FigureEnd.Open);

            return path;
        }
    }
}
